@@ -1,2 +1,2 @@
 from .generate import generate
-from .safe.safe import check
\ No newline at end of file
+from .safe import check
\ No newline at end of file
